@@ -1,5 +1,4 @@
-from .auth_error import AuthError
-from .rate_error import RateError
+from .errors import BaseError, RateError, AuthError
 from .us_kia import UsKia
 from .us_hyundai import UsHyundai
 from .ca_kia import CaKia
